@@ -10,9 +10,11 @@ import shutil
 import subprocess
 import tempfile
 
-import wheel.install
-import wheel.util
+from packaging import tags
+from pkg_resources import Distribution, Requirement
 
+from wheel_filename import InvalidFilenameError, parse_wheel_filename
+from wheel_inspect import Wheel, inspect_wheel
 
 class BuildError(Exception):
     def __init__(self, package, version, root_exception=None):
@@ -26,28 +28,42 @@ class BuildError(Exception):
 
 class Builder(object):
     """
-    Provides a context in which wheels can be generated. If the context goes out of scope all created files will be
-    removed.
+    Provides a context in which wheels can be generated. If the context goes out of scope
+    all created files will be removed.
     """
-
     def __enter__(self):
         self.scratch_dir = tempfile.mkdtemp()
         self.wheelhouse = path.join(self.scratch_dir, 'wheels')
         self.builddir = path.join(self.scratch_dir, 'build')
-        self.cachedir = path.join(self.scratch_dir, 'cache')
         return lambda *args: self.build(*args)
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         shutil.rmtree(self.scratch_dir)
 
+    def _matches_requirement(self, requirement, wheels):
+        """
+        List wheels matching a requirement.
+
+        :param requirement:str : The requirement to satisfy
+        :param wheels: List of wheels to search.
+        """
+        req = Requirement.parse(requirement)
+
+        matching = []
+        for wheel in wheels:
+            w = wheel.parsed_filename
+            dist = Distribution(project_name=w.project, version=w.version)
+            if dist in req:
+                matching.append(wheel.path)
+        return matching
+
+
     def _find_wheel(self, name, version):
         """
         Find a wheel with the given name and version
         """
-        candidates = [
-            wheel.install.WheelFile(filename) for filename in glob.glob(path.join(self.wheelhouse, '*.whl'))
-        ]
-        matches = wheel.util.matches_requirement('{}=={}'.format(name, version), candidates)
+        candidates = [Wheel(filename) for filename in glob.iglob(path.join(self.wheelhouse, '*.whl'))]
+        matches = self._matches_requirement('{}=={}'.format(name, version), candidates)
         if len(matches) > 0:
             return str(matches[0])
         else:
@@ -66,23 +82,50 @@ class Builder(object):
             subprocess.check_output([
                 'pip', 'wheel',
                 '--wheel-dir=' + self.wheelhouse,
-                '--download-cache=' + self.cachedir,
                 '--build=' + self.builddir,
                 '{}=={}'.format(package, version)
-            ])
+            ], stderr=subprocess.STDOUT)
             return self._find_wheel(package, version)
         except subprocess.CalledProcessError as e:
             raise BuildError(package, version, e)
 
 
-def is_pure(path):
+def is_pure(wheel):
     """
     Check whether wheel given by the passed path is pure.
 
     Pure wheels operate independent of the specific Python version and platform.
 
-    :param path: The path to the wheel to inspect
+    :param wheel: The path to the wheel to inspect
     :return: True if the wheel is pure
     """
-    wheel_file = wheel.install.WheelFile(path)
-    return wheel_file.parsed_wheel_info['Root-Is-Purelib'] == 'true'  # safe default
+    return (
+        inspect_wheel(wheel)
+            .get("dist_info", {})
+            .get("wheel", {})
+            .get("root_is_purelib")
+    )
+
+
+def is_compatible(package):
+    """
+    Check whether the given python package is a wheel compatible with the
+    current platform and python interpreter.
+
+    Compatibility is based on https://www.python.org/dev/peps/pep-0425/
+    """
+    try:
+        w = parse_wheel_filename(package)
+        for systag in tags.sys_tags():
+            for tag in w.tag_triples():
+                if systag in tags.parse_tag(tag):
+                    return True
+    except InvalidFilenameError:
+        return False
+
+
+def has_compatible_wheel(packages):
+    """
+    Check for a compatible wheel in the given list of python packages
+    """
+    return any(is_compatible(pkg) for pkg in packages)
